==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/main_tests.h <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <ranges.h>
#include <subtitle.h>
#include <subtitleline.h>
#include <subtitleiterator.h>
#include <audiolevels.h>

#include <qglobal.h>
#include <qstring.h>
#include <qdatetime.h>

#include <kdebug.h>

using namespace SubtitleComposer;

void showRanges( const RangeList& ranges )
{
	QString aux;
	for ( RangeList::ConstIterator it = ranges.begin(), end = ranges.end(); it != end; ++it )
		aux += QString( " [%1,%2]" ).arg( (*it).start() ).arg( (*it).end() );

	kdDebug() << QString( "Showing ranges: %1" ).arg( aux.stripWhiteSpace() ) << endl;
}

void addRange( RangeList& ranges, const Range& range )
{
	kdDebug() << QString( "Inserting range [%1,%2]" ).arg( range.start() ).arg( range.end() ) << endl;
	ranges << range;
	showRanges( ranges );
	kdDebug() << "--------------------------" << endl;
}

void clearRanges( RangeList& ranges )
{
	kdDebug() << "Clearing ranges" << endl;
	ranges.clear();
	showRanges( ranges );
}

void testRanges()
{
	RangeList ranges;

	addRange( ranges, Range( 1, 1 ) );
	addRange( ranges, Range( 10, 10 ) );
	addRange( ranges, Range( 12, 12 ) );
	addRange( ranges, Range( 14, 14 ) );
	addRange( ranges, Range( 16, 16 ) );
	addRange( ranges, Range( 5, 5 ) );

	clearRanges( ranges );

	addRange( ranges, Range( 1, 1 ) );
	addRange( ranges, Range( 5, 10 ) );
	addRange( ranges, Range( 10, 10 ) );
	addRange( ranges, Range( 11, 11 ) );
	addRange( ranges, Range( 15, 20 ) );
	addRange( ranges, Range( 3, 20 ) );
	addRange( ranges, Range( 1, 20 ) );

	kdDebug() << "Creating full() range" << endl;
	showRanges( Range::full() );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating lower( 500 ) range" << endl;
	showRanges( Range::lower( 500 ) );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating upper( 500 ) range" << endl;
	showRanges( Range::upper( 500 ) );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating upper( 500 ) range" << endl;
	ranges.clear();
	ranges << 5;
	kdDebug() << "contains 5: " << ranges.contains( 5 ) << endl;
	kdDebug() << "--------------------------" << endl;

}

void showSubtitle( const Subtitle& subtitle )
{
	kdDebug() << "Showing subtitle" << endl;
	for ( int index = 0, size = subtitle.linesCount(); index < size; ++index )
		kdDebug() << QString( "Line: %1" ).arg( subtitle.line( index )->primaryText() ) << endl;
	kdDebug() << "--------------------------" << endl;
}

void iterateSubtitle( const Subtitle& subtitle, const RangeList& ranges )
{
	showRanges( ranges );

	for ( int idx=0; idx < 3; ++idx )
	{
		kdDebug() << "Iterating subtitle forwards from ranges" << endl;
		for ( SubtitleIterator it( subtitle, ranges ); it.current(); ++it )
			kdDebug() << QString( "Line: %1" ).arg( it.current()->primaryText() ) << endl;

		kdDebug() << "Iterating subtitle backwards from ranges" << endl;
		for ( SubtitleIterator it( subtitle, ranges, true ); it.current(); --it )
			kdDebug() << QString( "Line: %1" ).arg( it.current()->primaryText() ) << endl;
	}

	kdDebug() << "--------------------------" << endl;
}

void testSubtitleIterator()
{
	Subtitle subtitle;

	for ( int index = 0; index < 20; ++index )
		subtitle.insertLine( new SubtitleLine( QString( "Line %1" ).arg( index ) ) );

	showSubtitle( subtitle );

	iterateSubtitle( subtitle, Range::full() );
	iterateSubtitle( subtitle, Range::lower( 10 ) );
	iterateSubtitle( subtitle, Range::upper( 10 ) );
	iterateSubtitle( subtitle, Range::lower( 50 ) );
	iterateSubtitle( subtitle, Range::upper( 50 ) );
	RangeList ranges;
	ranges << Range( 1, 3 );
	ranges << Range( 5, 5 );
	ranges << Range( 11, 17 );
	iterateSubtitle( subtitle, ranges );

// 	SubtitleIterator it( subtitle, ranges, true );
// 	for ( int idx = 0; idx < 100; ++idx )
// 		++it;
// 	for ( int idx = 0; idx < 200; ++idx )
// 		--it;

// 	SubtitleIterator it( subtitle, Range( 1, 50 ), true );
// 	for ( int idx = 0; idx < 100; ++idx )
// 		++it;
// 	for ( int idx = 0; idx < 200; ++idx )
// 		--it;

	/*QTime time;
	time.start();

	for ( SubtitleIterator it( subtitle, Range::full(), true ); it.current(); --it )
		it.current()->text();

	kdDebug() << time.elapsed() << endl;

	for ( SubtitleIterator it( subtitle, Range::full(), true ); it.current(); --it )
		it.current()->text();

	kdDebug() << time.elapsed() << endl;*/
}

void test_audiolevels()
{
	AudioLevels audiolevels;
	audiolevels.load( "/home/sergio/Desktop/scomp-trunk/SAMPLES/chasing.amy.cd1.wf" );
	audiolevels.save( "/home/sergio/Desktop/scomp-trunk/SAMPLES/chasing.amy.cd1.2.wf", true );
}

int main( int, char** )
{
// 	testRanges();
// 	testSubtitleIterator();

	test_audiolevels();
}

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/main_tests.h <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <range.h>
#include <rangelist.h>
#include <sstring.h>
#include <subtitle.h>
#include <subtitleline.h>
#include <subtitleiterator.h>
#include <audiolevels.h>

#include <qglobal.h>
#include <qstring.h>
#include <qdatetime.h>

#include <kdebug.h>

using namespace SubtitleComposer;

void showRanges( const RangeList& ranges )
{
	QString aux;
	for ( RangeList::ConstIterator it = ranges.begin(), end = ranges.end(); it != end; ++it )
		aux += QString( " [%1,%2]" ).arg( (*it).start() ).arg( (*it).end() );

	kdDebug() << QString( "Showing ranges: %1" ).arg( aux.stripWhiteSpace() ) << endl;
}

void addRange( RangeList& ranges, const Range& range )
{
	kdDebug() << QString( "Inserting range [%1,%2]" ).arg( range.start() ).arg( range.end() ) << endl;
	ranges << range;
	showRanges( ranges );
	kdDebug() << "--------------------------" << endl;
}

void clearRanges( RangeList& ranges )
{
	kdDebug() << "Clearing ranges" << endl;
	ranges.clear();
	showRanges( ranges );
}

void testRanges()
{
	RangeList ranges;

	addRange( ranges, Range( 1, 1 ) );
	addRange( ranges, Range( 10, 10 ) );
	addRange( ranges, Range( 12, 12 ) );
	addRange( ranges, Range( 14, 14 ) );
	addRange( ranges, Range( 16, 16 ) );
	addRange( ranges, Range( 5, 5 ) );

	clearRanges( ranges );

	addRange( ranges, Range( 1, 1 ) );
	addRange( ranges, Range( 5, 10 ) );
	addRange( ranges, Range( 10, 10 ) );
	addRange( ranges, Range( 11, 11 ) );
	addRange( ranges, Range( 15, 20 ) );
	addRange( ranges, Range( 3, 20 ) );
	addRange( ranges, Range( 1, 20 ) );

	kdDebug() << "Creating full() range" << endl;
	showRanges( Range::full() );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating lower( 500 ) range" << endl;
	showRanges( Range::lower( 500 ) );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating upper( 500 ) range" << endl;
	showRanges( Range::upper( 500 ) );
	kdDebug() << "--------------------------" << endl;

	kdDebug() << "Creating upper( 500 ) range" << endl;
	ranges.clear();
	ranges << 5;
	kdDebug() << "contains 5: " << ranges.contains( 5 ) << endl;
	kdDebug() << "--------------------------" << endl;

}

void showSubtitle( const Subtitle& subtitle )
{
	kdDebug() << "Showing subtitle" << endl;
	for ( int index = 0, size = subtitle.linesCount(); index < size; ++index )
		kdDebug() << QString( "Line: %1" ).arg( subtitle.line( index )->primaryText().richString() ) << endl;
	kdDebug() << "--------------------------" << endl;
}

void iterateSubtitle( const Subtitle& subtitle, const RangeList& ranges )
{
	showRanges( ranges );

	for ( int idx=0; idx < 3; ++idx )
	{
		kdDebug() << "Iterating subtitle forwards from ranges" << endl;
		for ( SubtitleIterator it( subtitle, ranges ); it.current(); ++it )
			kdDebug() << QString( "Line: %1" ).arg( it.current()->primaryText().richString() ) << endl;

		kdDebug() << "Iterating subtitle backwards from ranges" << endl;
		for ( SubtitleIterator it( subtitle, ranges, true ); it.current(); --it )
			kdDebug() << QString( "Line: %1" ).arg( it.current()->primaryText().richString() ) << endl;
	}

	kdDebug() << "--------------------------" << endl;
}

void testSubtitleIterator()
{
	Subtitle subtitle;

	for ( int index = 0; index < 20; ++index )
		subtitle.insertLine( new SubtitleLine( QString( "Line %1" ).arg( index ) ) );

	showSubtitle( subtitle );

	iterateSubtitle( subtitle, Range::full() );
	iterateSubtitle( subtitle, Range::lower( 10 ) );
	iterateSubtitle( subtitle, Range::upper( 10 ) );
	iterateSubtitle( subtitle, Range::lower( 50 ) );
	iterateSubtitle( subtitle, Range::upper( 50 ) );
	RangeList ranges;
	ranges << Range( 1, 3 );
	ranges << Range( 5, 5 );
	ranges << Range( 11, 17 );
	iterateSubtitle( subtitle, ranges );

// 	SubtitleIterator it( subtitle, ranges, true );
// 	for ( int idx = 0; idx < 100; ++idx )
// 		++it;
// 	for ( int idx = 0; idx < 200; ++idx )
// 		--it;

// 	SubtitleIterator it( subtitle, Range( 1, 50 ), true );
// 	for ( int idx = 0; idx < 100; ++idx )
// 		++it;
// 	for ( int idx = 0; idx < 200; ++idx )
// 		--it;

	/*QTime time;
	time.start();

	for ( SubtitleIterator it( subtitle, Range::full(), true ); it.current(); --it )
		it.current()->text();

	kdDebug() << time.elapsed() << endl;

	for ( SubtitleIterator it( subtitle, Range::full(), true ); it.current(); --it )
		it.current()->text();

	kdDebug() << time.elapsed() << endl;*/
}

void test_audiolevels()
{
	AudioLevels audiolevels;
	audiolevels.load( "/home/sergio/Desktop/scomp-trunk/SAMPLES/chasing.amy.cd1.wf" );
	audiolevels.save( "/home/sergio/Desktop/scomp-trunk/SAMPLES/chasing.amy.cd1.2.wf", true );
}

void test_sstring()
{
	SString sstring( "aaaaaa", SString::Italic );
	kdDebug() << sstring.richString() << endl;

	sstring.prepend( SString( "bbbbb", SString::Bold ) );
	kdDebug() << sstring.richString() << endl;

	sstring.append( SString( "cccccc", SString::Bold ) );
	kdDebug() << sstring.richString() << endl;

	sstring.setStyleFlags( Range::full(), SString::Underline, true );
	kdDebug() << sstring.richString() << endl;

	sstring.setStyleFlags( Range::full(), SString::Bold, true );
	kdDebug() << sstring.richString() << endl;

	sstring.setStyleFlags( Range::full(), SString::Italic, false );
	kdDebug() << sstring.richString() << endl;

	kdDebug() << (SString( "aaaa", 0 ) != SString( "bbbb", 0 )) << endl;
	kdDebug() << (SString( "aaaa", 0 ) != SString( "aaaa", 0 )) << endl;
	kdDebug() << (SString() != SString( "aaaa", 0 )) << endl;

}

int main( int, char** )
{
// 	testRanges();
// 	testSubtitleIterator();

	test_sstring();
}
